Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterWadjetServiceServer(s grpc.ServiceRegistrar, srv WadjetServiceServer)
- type CancelQueryRequest
- func (*CancelQueryRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CancelQueryRequest) GetQueryId() string
- func (*CancelQueryRequest) ProtoMessage()
- func (x *CancelQueryRequest) ProtoReflect() protoreflect.Message
- func (x *CancelQueryRequest) Reset()
- func (x *CancelQueryRequest) String() string
- type CancelQueryResponse
- func (*CancelQueryResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CancelQueryResponse) GetQueryId() string
- func (x *CancelQueryResponse) GetState() string
- func (*CancelQueryResponse) ProtoMessage()
- func (x *CancelQueryResponse) ProtoReflect() protoreflect.Message
- func (x *CancelQueryResponse) Reset()
- func (x *CancelQueryResponse) String() string
- type ColumnDef
- func (*ColumnDef) Descriptor() ([]byte, []int)deprecated
- func (x *ColumnDef) GetName() string
- func (x *ColumnDef) GetNullable() bool
- func (x *ColumnDef) GetType() string
- func (*ColumnDef) ProtoMessage()
- func (x *ColumnDef) ProtoReflect() protoreflect.Message
- func (x *ColumnDef) Reset()
- func (x *ColumnDef) String() string
- type ColumnInfo
- func (*ColumnInfo) Descriptor() ([]byte, []int)deprecated
- func (x *ColumnInfo) GetName() string
- func (x *ColumnInfo) GetNullable() bool
- func (x *ColumnInfo) GetType() string
- func (*ColumnInfo) ProtoMessage()
- func (x *ColumnInfo) ProtoReflect() protoreflect.Message
- func (x *ColumnInfo) Reset()
- func (x *ColumnInfo) String() string
- type CreateTableRequest
- func (*CreateTableRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateTableRequest) GetColumns() []*ColumnDef
- func (x *CreateTableRequest) GetName() string
- func (x *CreateTableRequest) GetPartitionKeys() []string
- func (*CreateTableRequest) ProtoMessage()
- func (x *CreateTableRequest) ProtoReflect() protoreflect.Message
- func (x *CreateTableRequest) Reset()
- func (x *CreateTableRequest) String() string
- type CreateTableResponse
- func (*CreateTableResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateTableResponse) GetName() string
- func (*CreateTableResponse) ProtoMessage()
- func (x *CreateTableResponse) ProtoReflect() protoreflect.Message
- func (x *CreateTableResponse) Reset()
- func (x *CreateTableResponse) String() string
- type DescribeTableRequest
- func (*DescribeTableRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DescribeTableRequest) GetTableName() string
- func (*DescribeTableRequest) ProtoMessage()
- func (x *DescribeTableRequest) ProtoReflect() protoreflect.Message
- func (x *DescribeTableRequest) Reset()
- func (x *DescribeTableRequest) String() string
- type DescribeTableResponse
- func (*DescribeTableResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DescribeTableResponse) GetColumns() []*ColumnInfo
- func (x *DescribeTableResponse) GetName() string
- func (x *DescribeTableResponse) GetPartitionKeys() []string
- func (*DescribeTableResponse) ProtoMessage()
- func (x *DescribeTableResponse) ProtoReflect() protoreflect.Message
- func (x *DescribeTableResponse) Reset()
- func (x *DescribeTableResponse) String() string
- type DropTableRequest
- func (*DropTableRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DropTableRequest) GetIfExists() bool
- func (x *DropTableRequest) GetName() string
- func (*DropTableRequest) ProtoMessage()
- func (x *DropTableRequest) ProtoReflect() protoreflect.Message
- func (x *DropTableRequest) Reset()
- func (x *DropTableRequest) String() string
- type DropTableResponse
- type GetQueryStatusRequest
- func (*GetQueryStatusRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetQueryStatusRequest) GetQueryId() string
- func (*GetQueryStatusRequest) ProtoMessage()
- func (x *GetQueryStatusRequest) ProtoReflect() protoreflect.Message
- func (x *GetQueryStatusRequest) Reset()
- func (x *GetQueryStatusRequest) String() string
- type GetQueryStatusResponse
- func (*GetQueryStatusResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetQueryStatusResponse) GetElapsed() *durationpb.Duration
- func (x *GetQueryStatusResponse) GetError() string
- func (x *GetQueryStatusResponse) GetQueryId() string
- func (x *GetQueryStatusResponse) GetSql() string
- func (x *GetQueryStatusResponse) GetStages() []*StageStatus
- func (x *GetQueryStatusResponse) GetState() string
- func (x *GetQueryStatusResponse) GetTotalRows() int64
- func (*GetQueryStatusResponse) ProtoMessage()
- func (x *GetQueryStatusResponse) ProtoReflect() protoreflect.Message
- func (x *GetQueryStatusResponse) Reset()
- func (x *GetQueryStatusResponse) String() string
- type ListTablesRequest
- type ListTablesResponse
- func (*ListTablesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListTablesResponse) GetTables() []string
- func (*ListTablesResponse) ProtoMessage()
- func (x *ListTablesResponse) ProtoReflect() protoreflect.Message
- func (x *ListTablesResponse) Reset()
- func (x *ListTablesResponse) String() string
- type QueryRequest
- type QueryResponse
- func (*QueryResponse) Descriptor() ([]byte, []int)deprecated
- func (x *QueryResponse) GetColumns() []string
- func (x *QueryResponse) GetQueryId() string
- func (x *QueryResponse) GetRows() []*Row
- func (x *QueryResponse) GetStats() *QueryStats
- func (*QueryResponse) ProtoMessage()
- func (x *QueryResponse) ProtoReflect() protoreflect.Message
- func (x *QueryResponse) Reset()
- func (x *QueryResponse) String() string
- type QueryStats
- func (*QueryStats) Descriptor() ([]byte, []int)deprecated
- func (x *QueryStats) GetElapsed() *durationpb.Duration
- func (x *QueryStats) GetPlan() string
- func (x *QueryStats) GetTotalRows() int64
- func (*QueryStats) ProtoMessage()
- func (x *QueryStats) ProtoReflect() protoreflect.Message
- func (x *QueryStats) Reset()
- func (x *QueryStats) String() string
- type QueryStreamResponse
- func (*QueryStreamResponse) Descriptor() ([]byte, []int)deprecated
- func (x *QueryStreamResponse) GetColumns() []string
- func (x *QueryStreamResponse) GetIsLast() bool
- func (x *QueryStreamResponse) GetRows() []*Row
- func (x *QueryStreamResponse) GetStats() *QueryStats
- func (*QueryStreamResponse) ProtoMessage()
- func (x *QueryStreamResponse) ProtoReflect() protoreflect.Message
- func (x *QueryStreamResponse) Reset()
- func (x *QueryStreamResponse) String() string
- type Row
- type StageStatus
- func (*StageStatus) Descriptor() ([]byte, []int)deprecated
- func (x *StageStatus) GetDoneTasks() int32
- func (x *StageStatus) GetFailedTasks() int32
- func (x *StageStatus) GetStageId() string
- func (x *StageStatus) GetTotalTasks() int32
- func (x *StageStatus) GetType() string
- func (*StageStatus) ProtoMessage()
- func (x *StageStatus) ProtoReflect() protoreflect.Message
- func (x *StageStatus) Reset()
- func (x *StageStatus) String() string
- type SubmitQueryResponse
- func (*SubmitQueryResponse) Descriptor() ([]byte, []int)deprecated
- func (x *SubmitQueryResponse) GetPlan() string
- func (x *SubmitQueryResponse) GetQueryId() string
- func (*SubmitQueryResponse) ProtoMessage()
- func (x *SubmitQueryResponse) ProtoReflect() protoreflect.Message
- func (x *SubmitQueryResponse) Reset()
- func (x *SubmitQueryResponse) String() string
- type UnimplementedWadjetServiceServer
- func (UnimplementedWadjetServiceServer) CancelQuery(context.Context, *CancelQueryRequest) (*CancelQueryResponse, error)
- func (UnimplementedWadjetServiceServer) CreateTable(context.Context, *CreateTableRequest) (*CreateTableResponse, error)
- func (UnimplementedWadjetServiceServer) DescribeTable(context.Context, *DescribeTableRequest) (*DescribeTableResponse, error)
- func (UnimplementedWadjetServiceServer) DropTable(context.Context, *DropTableRequest) (*DropTableResponse, error)
- func (UnimplementedWadjetServiceServer) GetQueryStatus(context.Context, *GetQueryStatusRequest) (*GetQueryStatusResponse, error)
- func (UnimplementedWadjetServiceServer) ListTables(context.Context, *ListTablesRequest) (*ListTablesResponse, error)
- func (UnimplementedWadjetServiceServer) Query(context.Context, *QueryRequest) (*QueryResponse, error)
- func (UnimplementedWadjetServiceServer) QueryStream(*QueryRequest, grpc.ServerStreamingServer[QueryStreamResponse]) error
- func (UnimplementedWadjetServiceServer) SubmitQuery(context.Context, *QueryRequest) (*SubmitQueryResponse, error)
- type UnsafeWadjetServiceServer
- type WadjetServiceClient
- type WadjetServiceServer
- type WadjetService_QueryStreamClient
- type WadjetService_QueryStreamServer
Constants ¶
const ( WadjetService_Query_FullMethodName = "/wadjet.v1.WadjetService/Query" WadjetService_QueryStream_FullMethodName = "/wadjet.v1.WadjetService/QueryStream" WadjetService_SubmitQuery_FullMethodName = "/wadjet.v1.WadjetService/SubmitQuery" WadjetService_GetQueryStatus_FullMethodName = "/wadjet.v1.WadjetService/GetQueryStatus" WadjetService_CancelQuery_FullMethodName = "/wadjet.v1.WadjetService/CancelQuery" WadjetService_ListTables_FullMethodName = "/wadjet.v1.WadjetService/ListTables" WadjetService_DescribeTable_FullMethodName = "/wadjet.v1.WadjetService/DescribeTable" WadjetService_CreateTable_FullMethodName = "/wadjet.v1.WadjetService/CreateTable" WadjetService_DropTable_FullMethodName = "/wadjet.v1.WadjetService/DropTable" )
Variables ¶
var File_wadjet_v1_wadjet_proto protoreflect.FileDescriptor
var WadjetService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "wadjet.v1.WadjetService", HandlerType: (*WadjetServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Query", Handler: _WadjetService_Query_Handler, }, { MethodName: "SubmitQuery", Handler: _WadjetService_SubmitQuery_Handler, }, { MethodName: "GetQueryStatus", Handler: _WadjetService_GetQueryStatus_Handler, }, { MethodName: "CancelQuery", Handler: _WadjetService_CancelQuery_Handler, }, { MethodName: "ListTables", Handler: _WadjetService_ListTables_Handler, }, { MethodName: "DescribeTable", Handler: _WadjetService_DescribeTable_Handler, }, { MethodName: "CreateTable", Handler: _WadjetService_CreateTable_Handler, }, { MethodName: "DropTable", Handler: _WadjetService_DropTable_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "QueryStream", Handler: _WadjetService_QueryStream_Handler, ServerStreams: true, }, }, Metadata: "wadjet/v1/wadjet.proto", }
WadjetService_ServiceDesc is the grpc.ServiceDesc for WadjetService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterWadjetServiceServer ¶
func RegisterWadjetServiceServer(s grpc.ServiceRegistrar, srv WadjetServiceServer)
Types ¶
type CancelQueryRequest ¶
type CancelQueryRequest struct {
QueryId string `protobuf:"bytes,1,opt,name=query_id,json=queryId,proto3" json:"query_id,omitempty"`
// contains filtered or unexported fields
}
CancelQueryRequest identifies a query to cancel.
func (*CancelQueryRequest) Descriptor
deprecated
func (*CancelQueryRequest) Descriptor() ([]byte, []int)
Deprecated: Use CancelQueryRequest.ProtoReflect.Descriptor instead.
func (*CancelQueryRequest) GetQueryId ¶
func (x *CancelQueryRequest) GetQueryId() string
func (*CancelQueryRequest) ProtoMessage ¶
func (*CancelQueryRequest) ProtoMessage()
func (*CancelQueryRequest) ProtoReflect ¶
func (x *CancelQueryRequest) ProtoReflect() protoreflect.Message
func (*CancelQueryRequest) Reset ¶
func (x *CancelQueryRequest) Reset()
func (*CancelQueryRequest) String ¶
func (x *CancelQueryRequest) String() string
type CancelQueryResponse ¶
type CancelQueryResponse struct {
QueryId string `protobuf:"bytes,1,opt,name=query_id,json=queryId,proto3" json:"query_id,omitempty"`
State string `protobuf:"bytes,2,opt,name=state,proto3" json:"state,omitempty"`
// contains filtered or unexported fields
}
CancelQueryResponse confirms cancellation.
func (*CancelQueryResponse) Descriptor
deprecated
func (*CancelQueryResponse) Descriptor() ([]byte, []int)
Deprecated: Use CancelQueryResponse.ProtoReflect.Descriptor instead.
func (*CancelQueryResponse) GetQueryId ¶
func (x *CancelQueryResponse) GetQueryId() string
func (*CancelQueryResponse) GetState ¶
func (x *CancelQueryResponse) GetState() string
func (*CancelQueryResponse) ProtoMessage ¶
func (*CancelQueryResponse) ProtoMessage()
func (*CancelQueryResponse) ProtoReflect ¶
func (x *CancelQueryResponse) ProtoReflect() protoreflect.Message
func (*CancelQueryResponse) Reset ¶
func (x *CancelQueryResponse) Reset()
func (*CancelQueryResponse) String ¶
func (x *CancelQueryResponse) String() string
type ColumnDef ¶
type ColumnDef struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
Nullable bool `protobuf:"varint,3,opt,name=nullable,proto3" json:"nullable,omitempty"`
// contains filtered or unexported fields
}
ColumnDef defines a column for table creation.
func (*ColumnDef) Descriptor
deprecated
func (*ColumnDef) GetNullable ¶
func (*ColumnDef) ProtoMessage ¶
func (*ColumnDef) ProtoMessage()
func (*ColumnDef) ProtoReflect ¶
func (x *ColumnDef) ProtoReflect() protoreflect.Message
type ColumnInfo ¶
type ColumnInfo struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
Nullable bool `protobuf:"varint,3,opt,name=nullable,proto3" json:"nullable,omitempty"`
// contains filtered or unexported fields
}
ColumnInfo describes a column in a table schema.
func (*ColumnInfo) Descriptor
deprecated
func (*ColumnInfo) Descriptor() ([]byte, []int)
Deprecated: Use ColumnInfo.ProtoReflect.Descriptor instead.
func (*ColumnInfo) GetName ¶
func (x *ColumnInfo) GetName() string
func (*ColumnInfo) GetNullable ¶
func (x *ColumnInfo) GetNullable() bool
func (*ColumnInfo) GetType ¶
func (x *ColumnInfo) GetType() string
func (*ColumnInfo) ProtoMessage ¶
func (*ColumnInfo) ProtoMessage()
func (*ColumnInfo) ProtoReflect ¶
func (x *ColumnInfo) ProtoReflect() protoreflect.Message
func (*ColumnInfo) Reset ¶
func (x *ColumnInfo) Reset()
func (*ColumnInfo) String ¶
func (x *ColumnInfo) String() string
type CreateTableRequest ¶
type CreateTableRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Columns []*ColumnDef `protobuf:"bytes,2,rep,name=columns,proto3" json:"columns,omitempty"`
PartitionKeys []string `protobuf:"bytes,3,rep,name=partition_keys,json=partitionKeys,proto3" json:"partition_keys,omitempty"`
// contains filtered or unexported fields
}
CreateTableRequest defines a new table.
func (*CreateTableRequest) Descriptor
deprecated
func (*CreateTableRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateTableRequest.ProtoReflect.Descriptor instead.
func (*CreateTableRequest) GetColumns ¶
func (x *CreateTableRequest) GetColumns() []*ColumnDef
func (*CreateTableRequest) GetName ¶
func (x *CreateTableRequest) GetName() string
func (*CreateTableRequest) GetPartitionKeys ¶
func (x *CreateTableRequest) GetPartitionKeys() []string
func (*CreateTableRequest) ProtoMessage ¶
func (*CreateTableRequest) ProtoMessage()
func (*CreateTableRequest) ProtoReflect ¶
func (x *CreateTableRequest) ProtoReflect() protoreflect.Message
func (*CreateTableRequest) Reset ¶
func (x *CreateTableRequest) Reset()
func (*CreateTableRequest) String ¶
func (x *CreateTableRequest) String() string
type CreateTableResponse ¶
type CreateTableResponse struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
CreateTableResponse confirms creation.
func (*CreateTableResponse) Descriptor
deprecated
func (*CreateTableResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateTableResponse.ProtoReflect.Descriptor instead.
func (*CreateTableResponse) GetName ¶
func (x *CreateTableResponse) GetName() string
func (*CreateTableResponse) ProtoMessage ¶
func (*CreateTableResponse) ProtoMessage()
func (*CreateTableResponse) ProtoReflect ¶
func (x *CreateTableResponse) ProtoReflect() protoreflect.Message
func (*CreateTableResponse) Reset ¶
func (x *CreateTableResponse) Reset()
func (*CreateTableResponse) String ¶
func (x *CreateTableResponse) String() string
type DescribeTableRequest ¶
type DescribeTableRequest struct {
TableName string `protobuf:"bytes,1,opt,name=table_name,json=tableName,proto3" json:"table_name,omitempty"`
// contains filtered or unexported fields
}
DescribeTableRequest identifies a table.
func (*DescribeTableRequest) Descriptor
deprecated
func (*DescribeTableRequest) Descriptor() ([]byte, []int)
Deprecated: Use DescribeTableRequest.ProtoReflect.Descriptor instead.
func (*DescribeTableRequest) GetTableName ¶
func (x *DescribeTableRequest) GetTableName() string
func (*DescribeTableRequest) ProtoMessage ¶
func (*DescribeTableRequest) ProtoMessage()
func (*DescribeTableRequest) ProtoReflect ¶
func (x *DescribeTableRequest) ProtoReflect() protoreflect.Message
func (*DescribeTableRequest) Reset ¶
func (x *DescribeTableRequest) Reset()
func (*DescribeTableRequest) String ¶
func (x *DescribeTableRequest) String() string
type DescribeTableResponse ¶
type DescribeTableResponse struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Columns []*ColumnInfo `protobuf:"bytes,2,rep,name=columns,proto3" json:"columns,omitempty"`
PartitionKeys []string `protobuf:"bytes,3,rep,name=partition_keys,json=partitionKeys,proto3" json:"partition_keys,omitempty"`
// contains filtered or unexported fields
}
DescribeTableResponse contains a table's schema.
func (*DescribeTableResponse) Descriptor
deprecated
func (*DescribeTableResponse) Descriptor() ([]byte, []int)
Deprecated: Use DescribeTableResponse.ProtoReflect.Descriptor instead.
func (*DescribeTableResponse) GetColumns ¶
func (x *DescribeTableResponse) GetColumns() []*ColumnInfo
func (*DescribeTableResponse) GetName ¶
func (x *DescribeTableResponse) GetName() string
func (*DescribeTableResponse) GetPartitionKeys ¶
func (x *DescribeTableResponse) GetPartitionKeys() []string
func (*DescribeTableResponse) ProtoMessage ¶
func (*DescribeTableResponse) ProtoMessage()
func (*DescribeTableResponse) ProtoReflect ¶
func (x *DescribeTableResponse) ProtoReflect() protoreflect.Message
func (*DescribeTableResponse) Reset ¶
func (x *DescribeTableResponse) Reset()
func (*DescribeTableResponse) String ¶
func (x *DescribeTableResponse) String() string
type DropTableRequest ¶
type DropTableRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
IfExists bool `protobuf:"varint,2,opt,name=if_exists,json=ifExists,proto3" json:"if_exists,omitempty"`
// contains filtered or unexported fields
}
DropTableRequest identifies a table to drop.
func (*DropTableRequest) Descriptor
deprecated
func (*DropTableRequest) Descriptor() ([]byte, []int)
Deprecated: Use DropTableRequest.ProtoReflect.Descriptor instead.
func (*DropTableRequest) GetIfExists ¶
func (x *DropTableRequest) GetIfExists() bool
func (*DropTableRequest) GetName ¶
func (x *DropTableRequest) GetName() string
func (*DropTableRequest) ProtoMessage ¶
func (*DropTableRequest) ProtoMessage()
func (*DropTableRequest) ProtoReflect ¶
func (x *DropTableRequest) ProtoReflect() protoreflect.Message
func (*DropTableRequest) Reset ¶
func (x *DropTableRequest) Reset()
func (*DropTableRequest) String ¶
func (x *DropTableRequest) String() string
type DropTableResponse ¶
type DropTableResponse struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
DropTableResponse confirms deletion.
func (*DropTableResponse) Descriptor
deprecated
func (*DropTableResponse) Descriptor() ([]byte, []int)
Deprecated: Use DropTableResponse.ProtoReflect.Descriptor instead.
func (*DropTableResponse) GetName ¶
func (x *DropTableResponse) GetName() string
func (*DropTableResponse) ProtoMessage ¶
func (*DropTableResponse) ProtoMessage()
func (*DropTableResponse) ProtoReflect ¶
func (x *DropTableResponse) ProtoReflect() protoreflect.Message
func (*DropTableResponse) Reset ¶
func (x *DropTableResponse) Reset()
func (*DropTableResponse) String ¶
func (x *DropTableResponse) String() string
type GetQueryStatusRequest ¶
type GetQueryStatusRequest struct {
QueryId string `protobuf:"bytes,1,opt,name=query_id,json=queryId,proto3" json:"query_id,omitempty"`
// contains filtered or unexported fields
}
GetQueryStatusRequest identifies a query to check.
func (*GetQueryStatusRequest) Descriptor
deprecated
func (*GetQueryStatusRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetQueryStatusRequest.ProtoReflect.Descriptor instead.
func (*GetQueryStatusRequest) GetQueryId ¶
func (x *GetQueryStatusRequest) GetQueryId() string
func (*GetQueryStatusRequest) ProtoMessage ¶
func (*GetQueryStatusRequest) ProtoMessage()
func (*GetQueryStatusRequest) ProtoReflect ¶
func (x *GetQueryStatusRequest) ProtoReflect() protoreflect.Message
func (*GetQueryStatusRequest) Reset ¶
func (x *GetQueryStatusRequest) Reset()
func (*GetQueryStatusRequest) String ¶
func (x *GetQueryStatusRequest) String() string
type GetQueryStatusResponse ¶
type GetQueryStatusResponse struct {
QueryId string `protobuf:"bytes,1,opt,name=query_id,json=queryId,proto3" json:"query_id,omitempty"`
Sql string `protobuf:"bytes,2,opt,name=sql,proto3" json:"sql,omitempty"`
State string `protobuf:"bytes,3,opt,name=state,proto3" json:"state,omitempty"`
Stages []*StageStatus `protobuf:"bytes,4,rep,name=stages,proto3" json:"stages,omitempty"`
Elapsed *durationpb.Duration `protobuf:"bytes,5,opt,name=elapsed,proto3" json:"elapsed,omitempty"`
TotalRows int64 `protobuf:"varint,6,opt,name=total_rows,json=totalRows,proto3" json:"total_rows,omitempty"`
Error string `protobuf:"bytes,7,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
GetQueryStatusResponse reports the current state of a query.
func (*GetQueryStatusResponse) Descriptor
deprecated
func (*GetQueryStatusResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetQueryStatusResponse.ProtoReflect.Descriptor instead.
func (*GetQueryStatusResponse) GetElapsed ¶
func (x *GetQueryStatusResponse) GetElapsed() *durationpb.Duration
func (*GetQueryStatusResponse) GetError ¶
func (x *GetQueryStatusResponse) GetError() string
func (*GetQueryStatusResponse) GetQueryId ¶
func (x *GetQueryStatusResponse) GetQueryId() string
func (*GetQueryStatusResponse) GetSql ¶
func (x *GetQueryStatusResponse) GetSql() string
func (*GetQueryStatusResponse) GetStages ¶
func (x *GetQueryStatusResponse) GetStages() []*StageStatus
func (*GetQueryStatusResponse) GetState ¶
func (x *GetQueryStatusResponse) GetState() string
func (*GetQueryStatusResponse) GetTotalRows ¶
func (x *GetQueryStatusResponse) GetTotalRows() int64
func (*GetQueryStatusResponse) ProtoMessage ¶
func (*GetQueryStatusResponse) ProtoMessage()
func (*GetQueryStatusResponse) ProtoReflect ¶
func (x *GetQueryStatusResponse) ProtoReflect() protoreflect.Message
func (*GetQueryStatusResponse) Reset ¶
func (x *GetQueryStatusResponse) Reset()
func (*GetQueryStatusResponse) String ¶
func (x *GetQueryStatusResponse) String() string
type ListTablesRequest ¶
type ListTablesRequest struct {
// contains filtered or unexported fields
}
ListTablesRequest is empty.
func (*ListTablesRequest) Descriptor
deprecated
func (*ListTablesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListTablesRequest.ProtoReflect.Descriptor instead.
func (*ListTablesRequest) ProtoMessage ¶
func (*ListTablesRequest) ProtoMessage()
func (*ListTablesRequest) ProtoReflect ¶
func (x *ListTablesRequest) ProtoReflect() protoreflect.Message
func (*ListTablesRequest) Reset ¶
func (x *ListTablesRequest) Reset()
func (*ListTablesRequest) String ¶
func (x *ListTablesRequest) String() string
type ListTablesResponse ¶
type ListTablesResponse struct {
Tables []string `protobuf:"bytes,1,rep,name=tables,proto3" json:"tables,omitempty"`
// contains filtered or unexported fields
}
ListTablesResponse contains all table names.
func (*ListTablesResponse) Descriptor
deprecated
func (*ListTablesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListTablesResponse.ProtoReflect.Descriptor instead.
func (*ListTablesResponse) GetTables ¶
func (x *ListTablesResponse) GetTables() []string
func (*ListTablesResponse) ProtoMessage ¶
func (*ListTablesResponse) ProtoMessage()
func (*ListTablesResponse) ProtoReflect ¶
func (x *ListTablesResponse) ProtoReflect() protoreflect.Message
func (*ListTablesResponse) Reset ¶
func (x *ListTablesResponse) Reset()
func (*ListTablesResponse) String ¶
func (x *ListTablesResponse) String() string
type QueryRequest ¶
type QueryRequest struct {
Sql string `protobuf:"bytes,1,opt,name=sql,proto3" json:"sql,omitempty"`
// contains filtered or unexported fields
}
QueryRequest is used for both synchronous and streaming queries.
func (*QueryRequest) Descriptor
deprecated
func (*QueryRequest) Descriptor() ([]byte, []int)
Deprecated: Use QueryRequest.ProtoReflect.Descriptor instead.
func (*QueryRequest) GetSql ¶
func (x *QueryRequest) GetSql() string
func (*QueryRequest) ProtoMessage ¶
func (*QueryRequest) ProtoMessage()
func (*QueryRequest) ProtoReflect ¶
func (x *QueryRequest) ProtoReflect() protoreflect.Message
func (*QueryRequest) Reset ¶
func (x *QueryRequest) Reset()
func (*QueryRequest) String ¶
func (x *QueryRequest) String() string
type QueryResponse ¶
type QueryResponse struct {
QueryId string `protobuf:"bytes,1,opt,name=query_id,json=queryId,proto3" json:"query_id,omitempty"`
Columns []string `protobuf:"bytes,2,rep,name=columns,proto3" json:"columns,omitempty"`
Rows []*Row `protobuf:"bytes,3,rep,name=rows,proto3" json:"rows,omitempty"`
Stats *QueryStats `protobuf:"bytes,4,opt,name=stats,proto3" json:"stats,omitempty"`
// contains filtered or unexported fields
}
QueryResponse contains the full result of a synchronous query.
func (*QueryResponse) Descriptor
deprecated
func (*QueryResponse) Descriptor() ([]byte, []int)
Deprecated: Use QueryResponse.ProtoReflect.Descriptor instead.
func (*QueryResponse) GetColumns ¶
func (x *QueryResponse) GetColumns() []string
func (*QueryResponse) GetQueryId ¶
func (x *QueryResponse) GetQueryId() string
func (*QueryResponse) GetRows ¶
func (x *QueryResponse) GetRows() []*Row
func (*QueryResponse) GetStats ¶
func (x *QueryResponse) GetStats() *QueryStats
func (*QueryResponse) ProtoMessage ¶
func (*QueryResponse) ProtoMessage()
func (*QueryResponse) ProtoReflect ¶
func (x *QueryResponse) ProtoReflect() protoreflect.Message
func (*QueryResponse) Reset ¶
func (x *QueryResponse) Reset()
func (*QueryResponse) String ¶
func (x *QueryResponse) String() string
type QueryStats ¶
type QueryStats struct {
TotalRows int64 `protobuf:"varint,1,opt,name=total_rows,json=totalRows,proto3" json:"total_rows,omitempty"`
Elapsed *durationpb.Duration `protobuf:"bytes,2,opt,name=elapsed,proto3" json:"elapsed,omitempty"`
Plan string `protobuf:"bytes,3,opt,name=plan,proto3" json:"plan,omitempty"`
// contains filtered or unexported fields
}
QueryStats contains execution statistics.
func (*QueryStats) Descriptor
deprecated
func (*QueryStats) Descriptor() ([]byte, []int)
Deprecated: Use QueryStats.ProtoReflect.Descriptor instead.
func (*QueryStats) GetElapsed ¶
func (x *QueryStats) GetElapsed() *durationpb.Duration
func (*QueryStats) GetPlan ¶
func (x *QueryStats) GetPlan() string
func (*QueryStats) GetTotalRows ¶
func (x *QueryStats) GetTotalRows() int64
func (*QueryStats) ProtoMessage ¶
func (*QueryStats) ProtoMessage()
func (*QueryStats) ProtoReflect ¶
func (x *QueryStats) ProtoReflect() protoreflect.Message
func (*QueryStats) Reset ¶
func (x *QueryStats) Reset()
func (*QueryStats) String ¶
func (x *QueryStats) String() string
type QueryStreamResponse ¶
type QueryStreamResponse struct {
Columns []string `protobuf:"bytes,1,rep,name=columns,proto3" json:"columns,omitempty"`
Rows []*Row `protobuf:"bytes,2,rep,name=rows,proto3" json:"rows,omitempty"`
Stats *QueryStats `protobuf:"bytes,3,opt,name=stats,proto3" json:"stats,omitempty"`
IsLast bool `protobuf:"varint,4,opt,name=is_last,json=isLast,proto3" json:"is_last,omitempty"`
// contains filtered or unexported fields
}
QueryStreamResponse contains a batch of rows in a streaming query.
func (*QueryStreamResponse) Descriptor
deprecated
func (*QueryStreamResponse) Descriptor() ([]byte, []int)
Deprecated: Use QueryStreamResponse.ProtoReflect.Descriptor instead.
func (*QueryStreamResponse) GetColumns ¶
func (x *QueryStreamResponse) GetColumns() []string
func (*QueryStreamResponse) GetIsLast ¶
func (x *QueryStreamResponse) GetIsLast() bool
func (*QueryStreamResponse) GetRows ¶
func (x *QueryStreamResponse) GetRows() []*Row
func (*QueryStreamResponse) GetStats ¶
func (x *QueryStreamResponse) GetStats() *QueryStats
func (*QueryStreamResponse) ProtoMessage ¶
func (*QueryStreamResponse) ProtoMessage()
func (*QueryStreamResponse) ProtoReflect ¶
func (x *QueryStreamResponse) ProtoReflect() protoreflect.Message
func (*QueryStreamResponse) Reset ¶
func (x *QueryStreamResponse) Reset()
func (*QueryStreamResponse) String ¶
func (x *QueryStreamResponse) String() string
type Row ¶
type Row struct {
Fields map[string]*structpb.Value `` /* 139-byte string literal not displayed */
// The same row POSITIONALLY, aligned with QueryResponse.columns. A map
// cannot represent two output columns that publish ONE NAME, which is an
// ordinary result since PostgreSQL's naming rule was adopted:
// `SELECT g + 1, g + 2, g + 3` is three columns called `?column?`, and
// `fields` carries one key for the three of them. Sent whenever the result's
// column names are not unique; a client that needs every value reads this.
Values []*structpb.Value `protobuf:"bytes,2,rep,name=values,proto3" json:"values,omitempty"`
// contains filtered or unexported fields
}
Row represents a single result row as a map of column name to value.
func (*Row) Descriptor
deprecated
func (*Row) ProtoMessage ¶
func (*Row) ProtoMessage()
func (*Row) ProtoReflect ¶
func (x *Row) ProtoReflect() protoreflect.Message
type StageStatus ¶
type StageStatus struct {
StageId string `protobuf:"bytes,1,opt,name=stage_id,json=stageId,proto3" json:"stage_id,omitempty"`
Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
TotalTasks int32 `protobuf:"varint,3,opt,name=total_tasks,json=totalTasks,proto3" json:"total_tasks,omitempty"`
DoneTasks int32 `protobuf:"varint,4,opt,name=done_tasks,json=doneTasks,proto3" json:"done_tasks,omitempty"`
FailedTasks int32 `protobuf:"varint,5,opt,name=failed_tasks,json=failedTasks,proto3" json:"failed_tasks,omitempty"`
// contains filtered or unexported fields
}
StageStatus reports progress on a single query stage.
func (*StageStatus) Descriptor
deprecated
func (*StageStatus) Descriptor() ([]byte, []int)
Deprecated: Use StageStatus.ProtoReflect.Descriptor instead.
func (*StageStatus) GetDoneTasks ¶
func (x *StageStatus) GetDoneTasks() int32
func (*StageStatus) GetFailedTasks ¶
func (x *StageStatus) GetFailedTasks() int32
func (*StageStatus) GetStageId ¶
func (x *StageStatus) GetStageId() string
func (*StageStatus) GetTotalTasks ¶
func (x *StageStatus) GetTotalTasks() int32
func (*StageStatus) GetType ¶
func (x *StageStatus) GetType() string
func (*StageStatus) ProtoMessage ¶
func (*StageStatus) ProtoMessage()
func (*StageStatus) ProtoReflect ¶
func (x *StageStatus) ProtoReflect() protoreflect.Message
func (*StageStatus) Reset ¶
func (x *StageStatus) Reset()
func (*StageStatus) String ¶
func (x *StageStatus) String() string
type SubmitQueryResponse ¶
type SubmitQueryResponse struct {
QueryId string `protobuf:"bytes,1,opt,name=query_id,json=queryId,proto3" json:"query_id,omitempty"`
Plan string `protobuf:"bytes,2,opt,name=plan,proto3" json:"plan,omitempty"`
// contains filtered or unexported fields
}
SubmitQueryResponse is returned when an async query is submitted.
func (*SubmitQueryResponse) Descriptor
deprecated
func (*SubmitQueryResponse) Descriptor() ([]byte, []int)
Deprecated: Use SubmitQueryResponse.ProtoReflect.Descriptor instead.
func (*SubmitQueryResponse) GetPlan ¶
func (x *SubmitQueryResponse) GetPlan() string
func (*SubmitQueryResponse) GetQueryId ¶
func (x *SubmitQueryResponse) GetQueryId() string
func (*SubmitQueryResponse) ProtoMessage ¶
func (*SubmitQueryResponse) ProtoMessage()
func (*SubmitQueryResponse) ProtoReflect ¶
func (x *SubmitQueryResponse) ProtoReflect() protoreflect.Message
func (*SubmitQueryResponse) Reset ¶
func (x *SubmitQueryResponse) Reset()
func (*SubmitQueryResponse) String ¶
func (x *SubmitQueryResponse) String() string
type UnimplementedWadjetServiceServer ¶
type UnimplementedWadjetServiceServer struct{}
UnimplementedWadjetServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedWadjetServiceServer) CancelQuery ¶
func (UnimplementedWadjetServiceServer) CancelQuery(context.Context, *CancelQueryRequest) (*CancelQueryResponse, error)
func (UnimplementedWadjetServiceServer) CreateTable ¶
func (UnimplementedWadjetServiceServer) CreateTable(context.Context, *CreateTableRequest) (*CreateTableResponse, error)
func (UnimplementedWadjetServiceServer) DescribeTable ¶
func (UnimplementedWadjetServiceServer) DescribeTable(context.Context, *DescribeTableRequest) (*DescribeTableResponse, error)
func (UnimplementedWadjetServiceServer) DropTable ¶
func (UnimplementedWadjetServiceServer) DropTable(context.Context, *DropTableRequest) (*DropTableResponse, error)
func (UnimplementedWadjetServiceServer) GetQueryStatus ¶
func (UnimplementedWadjetServiceServer) GetQueryStatus(context.Context, *GetQueryStatusRequest) (*GetQueryStatusResponse, error)
func (UnimplementedWadjetServiceServer) ListTables ¶
func (UnimplementedWadjetServiceServer) ListTables(context.Context, *ListTablesRequest) (*ListTablesResponse, error)
func (UnimplementedWadjetServiceServer) Query ¶
func (UnimplementedWadjetServiceServer) Query(context.Context, *QueryRequest) (*QueryResponse, error)
func (UnimplementedWadjetServiceServer) QueryStream ¶
func (UnimplementedWadjetServiceServer) QueryStream(*QueryRequest, grpc.ServerStreamingServer[QueryStreamResponse]) error
func (UnimplementedWadjetServiceServer) SubmitQuery ¶
func (UnimplementedWadjetServiceServer) SubmitQuery(context.Context, *QueryRequest) (*SubmitQueryResponse, error)
type UnsafeWadjetServiceServer ¶
type UnsafeWadjetServiceServer interface {
// contains filtered or unexported methods
}
UnsafeWadjetServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to WadjetServiceServer will result in compilation errors.
type WadjetServiceClient ¶
type WadjetServiceClient interface {
// Execute a SQL query and return all results.
Query(ctx context.Context, in *QueryRequest, opts ...grpc.CallOption) (*QueryResponse, error)
// Execute a SQL query and stream result batches.
QueryStream(ctx context.Context, in *QueryRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[QueryStreamResponse], error)
// Submit a query for async execution (distributed mode).
SubmitQuery(ctx context.Context, in *QueryRequest, opts ...grpc.CallOption) (*SubmitQueryResponse, error)
// Get the status of an async query.
GetQueryStatus(ctx context.Context, in *GetQueryStatusRequest, opts ...grpc.CallOption) (*GetQueryStatusResponse, error)
// Cancel a running query.
CancelQuery(ctx context.Context, in *CancelQueryRequest, opts ...grpc.CallOption) (*CancelQueryResponse, error)
// List all tables.
ListTables(ctx context.Context, in *ListTablesRequest, opts ...grpc.CallOption) (*ListTablesResponse, error)
// Describe a table's schema.
DescribeTable(ctx context.Context, in *DescribeTableRequest, opts ...grpc.CallOption) (*DescribeTableResponse, error)
// Create a table.
CreateTable(ctx context.Context, in *CreateTableRequest, opts ...grpc.CallOption) (*CreateTableResponse, error)
// Drop a table.
DropTable(ctx context.Context, in *DropTableRequest, opts ...grpc.CallOption) (*DropTableResponse, error)
}
WadjetServiceClient is the client API for WadjetService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
WadjetService exposes Wadjet's query engine over gRPC.
func NewWadjetServiceClient ¶
func NewWadjetServiceClient(cc grpc.ClientConnInterface) WadjetServiceClient
type WadjetServiceServer ¶
type WadjetServiceServer interface {
// Execute a SQL query and return all results.
Query(context.Context, *QueryRequest) (*QueryResponse, error)
// Execute a SQL query and stream result batches.
QueryStream(*QueryRequest, grpc.ServerStreamingServer[QueryStreamResponse]) error
// Submit a query for async execution (distributed mode).
SubmitQuery(context.Context, *QueryRequest) (*SubmitQueryResponse, error)
// Get the status of an async query.
GetQueryStatus(context.Context, *GetQueryStatusRequest) (*GetQueryStatusResponse, error)
// Cancel a running query.
CancelQuery(context.Context, *CancelQueryRequest) (*CancelQueryResponse, error)
// List all tables.
ListTables(context.Context, *ListTablesRequest) (*ListTablesResponse, error)
// Describe a table's schema.
DescribeTable(context.Context, *DescribeTableRequest) (*DescribeTableResponse, error)
// Create a table.
CreateTable(context.Context, *CreateTableRequest) (*CreateTableResponse, error)
// Drop a table.
DropTable(context.Context, *DropTableRequest) (*DropTableResponse, error)
// contains filtered or unexported methods
}
WadjetServiceServer is the server API for WadjetService service. All implementations must embed UnimplementedWadjetServiceServer for forward compatibility.
WadjetService exposes Wadjet's query engine over gRPC.
type WadjetService_QueryStreamClient ¶
type WadjetService_QueryStreamClient = grpc.ServerStreamingClient[QueryStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type WadjetService_QueryStreamServer ¶
type WadjetService_QueryStreamServer = grpc.ServerStreamingServer[QueryStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.